summaryrefslogtreecommitdiffstats
path: root/src/H5Vprivate.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2012-02-10 19:48:08 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2012-02-10 19:48:08 (GMT)
commit5f94d17285913b2497d169cadfb639f300773407 (patch)
treef4a96b86d8ac5d13411ca897e1377fb2f1808cb3 /src/H5Vprivate.h
parentf16098f402139aa4e258542661c3003389803de9 (diff)
downloadhdf5-5f94d17285913b2497d169cadfb639f300773407.zip
hdf5-5f94d17285913b2497d169cadfb639f300773407.tar.gz
hdf5-5f94d17285913b2497d169cadfb639f300773407.tar.bz2
[svn-r21925] Description:
Bring r21919-21924 from trunk to 1.8 branch: cleanup FUNC_ENTER macros, etc. Also removed Subversion mergeinfo tags from a few directories and files. These are artifacts from non-root merges using pre-1.6 Subversion clients. (This should fix the problem of unchanged directories looking "changed" during checkins.) Tested on: Mac OSX/64 10.7.3 (amazon) w/debug & production (daily tested on trunk)
Diffstat (limited to 'src/H5Vprivate.h')
-rw-r--r--src/H5Vprivate.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/H5Vprivate.h b/src/H5Vprivate.h
index 894ec5c..29d75cf 100644
--- a/src/H5Vprivate.h
+++ b/src/H5Vprivate.h
@@ -126,8 +126,8 @@ H5V_vector_reduce_product(unsigned n, const hsize_t *v)
{
hsize_t ret_value = 1;
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_reduce_product)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (n && !v) HGOTO_DONE(0)
while (n--) ret_value *= *v++;
@@ -158,8 +158,8 @@ H5V_vector_zerop_u(int n, const hsize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_zerop_u)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (!v)
HGOTO_DONE(TRUE)
@@ -193,8 +193,8 @@ H5V_vector_zerop_s(int n, const hssize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_zerop_s)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (!v)
HGOTO_DONE(TRUE)
@@ -230,8 +230,8 @@ H5V_vector_cmp_u (unsigned n, const hsize_t *v1, const hsize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_cmp_u)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (v1 == v2) HGOTO_DONE(0)
if (v1 == NULL) HGOTO_DONE(-1)
@@ -272,8 +272,8 @@ H5V_vector_cmp_s (unsigned n, const hssize_t *v1, const hssize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_cmp_s)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (v1 == v2) HGOTO_DONE(0)
if (v1 == NULL) HGOTO_DONE(-1)